@@ -40,16 +40,6 @@ void RefactoringClient::alive()
         m_connectionClient->resetProcessAliveTimer();
 }
 
-void RefactoringClient::sourceLocationsForRenamingMessage(
-        ClangBackEnd::SourceLocationsForRenamingMessage &&message)
-{
-    m_localRenamingCallback(message.symbolName.toQString(),
-                            message.sourceLocations,
-                            message.textDocumentRevision);
-
-    m_refactoringEngine->setRefactoringEngineAvailable(true);
-}
-
 void RefactoringClient::sourceRangesAndDiagnosticsForQueryMessage(
         ClangBackEnd::SourceRangesAndDiagnosticsForQueryMessage &&message)
 {
@@ -64,12 +54,6 @@ void RefactoringClient::sourceRangesForQueryMessage(ClangBackEnd::SourceRangesFo
     setResultCounterAndSendSearchIsFinishedIfFinished();
 }
 
-void RefactoringClient::setLocalRenamingCallback(
-        CppTools::RefactoringEngineInterface::RenameCallback &&localRenamingCallback)
-{
-    m_localRenamingCallback = std::move(localRenamingCallback);
-}
-
 void RefactoringClient::progress(ClangBackEnd::ProgressMessage &&message)
 {
     m_progressManager.setProgress(message.progress, message.total);
@@ -100,11 +84,6 @@ void RefactoringClient::setClangQueryHighlighter(ClangQueryHighlighter *highligh
     m_clangQueryHighlighter = highlighter;
 }
 
-bool RefactoringClient::hasValidLocalRenamingCallback() const
-{
-    return bool(m_localRenamingCallback);
-}
-
 void RefactoringClient::setExpectedResultCount(uint count)
 {
     m_expectedResultCount = count;
@@ -141,11 +120,9 @@ void RefactoringClient::addSearchResult(const ClangBackEnd::SourceRangeWithTextC
     m_searchHandle->addResult(QString(filePathCache.filePath(sourceRangeWithText.filePathId()).path()),
                               QString(sourceRangeWithText.text),
                               {{int(sourceRangeWithText.start.line),
-                                int(sourceRangeWithText.start.column - 1),
-                                int(sourceRangeWithText.start.offset)},
+                                int(sourceRangeWithText.start.column - 1)},
                                {int(sourceRangeWithText.end.line),
-                                int(sourceRangeWithText.end.column - 1),
-                                int(sourceRangeWithText.end.offset)}});
+                                int(sourceRangeWithText.end.column - 1)}});
 }
 
 void RefactoringClient::setResultCounterAndSendSearchIsFinishedIfFinished()
