@@ -33,6 +33,7 @@
 #include <utils/fancylineedit.h>
 #include <utils/pathchooser.h>
 #include <utils/runextensions.h>
+#include <utils/stringutils.h>
 
 #include <QDialogButtonBox>
 #include <QDir>
@@ -53,13 +54,13 @@ SelectableFilesModel::SelectableFilesModel(QObject *parent) : QAbstractItemModel
     m_root = new Tree;
 }
 
-void SelectableFilesModel::setInitialMarkedFiles(const Utils::FileNameList &files)
+void SelectableFilesModel::setInitialMarkedFiles(const Utils::FilePaths &files)
 {
-    m_files = files.toSet();
+    m_files = Utils::toSet(files);
     m_allFiles = files.isEmpty();
 }
 
-void SelectableFilesFromDirModel::startParsing(const Utils::FileName &baseDir)
+void SelectableFilesFromDirModel::startParsing(const Utils::FilePath &baseDir)
 {
     m_watcher.cancel();
     m_watcher.waitForFinished();
@@ -87,7 +88,7 @@ void SelectableFilesFromDirModel::buildTreeFinished()
     m_root = m_rootForFuture;
     m_rootForFuture = nullptr;
     m_outOfBaseDirFiles
-            = Utils::filtered(m_files, [this](const Utils::FileName &fn) { return !fn.isChildOf(m_baseDir); });
+            = Utils::filtered(m_files, [this](const Utils::FilePath &fn) { return !fn.isChildOf(m_baseDir); });
 
     endResetModel();
     emit parsingFinished();
@@ -116,7 +117,7 @@ SelectableFilesModel::FilterState SelectableFilesModel::filter(Tree *t)
     return Utils::anyOf(m_hideFilesFilter, matchesTreeName) ? FilterState::HIDDEN : FilterState::SHOWN;
 }
 
-void SelectableFilesFromDirModel::buildTree(const Utils::FileName &baseDir, Tree *tree,
+void SelectableFilesFromDirModel::buildTree(const Utils::FilePath &baseDir, Tree *tree,
                                             QFutureInterface<void> &fi, int symlinkDepth)
 {
     if (symlinkDepth == 0)
@@ -128,7 +129,7 @@ void SelectableFilesFromDirModel::buildTree(const Utils::FileName &baseDir, Tree
     bool allChecked = true;
     bool allUnchecked = true;
     for (const QFileInfo &fileInfo : fileInfoList) {
-        Utils::FileName fn = Utils::FileName(fileInfo);
+        Utils::FilePath fn = Utils::FilePath::fromFileInfo(fileInfo);
         if (m_futureCount % 100) {
             emit parsingProgress(fn);
             if (fi.isCanceled())
@@ -298,18 +299,18 @@ void SelectableFilesModel::propagateDown(const QModelIndex &idx)
 
 Qt::ItemFlags SelectableFilesModel::flags(const QModelIndex &index) const
 {
-    Q_UNUSED(index);
+    Q_UNUSED(index)
     return Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsUserCheckable;
 }
 
-Utils::FileNameList SelectableFilesModel::selectedPaths() const
+Utils::FilePaths SelectableFilesModel::selectedPaths() const
 {
-    Utils::FileNameList result;
+    Utils::FilePaths result;
     collectPaths(m_root, &result);
     return result;
 }
 
-void SelectableFilesModel::collectPaths(Tree *root, Utils::FileNameList *result)  const
+void SelectableFilesModel::collectPaths(Tree *root, Utils::FilePaths *result)  const
 {
     if (root->checked == Qt::Unchecked)
         return;
@@ -318,16 +319,16 @@ void SelectableFilesModel::collectPaths(Tree *root, Utils::FileNameList *result)
         collectPaths(t, result);
 }
 
-Utils::FileNameList SelectableFilesModel::selectedFiles() const
+Utils::FilePaths SelectableFilesModel::selectedFiles() const
 {
-    Utils::FileNameList result = m_outOfBaseDirFiles.toList();
+    Utils::FilePaths result = Utils::toList(m_outOfBaseDirFiles);
     collectFiles(m_root, &result);
     return result;
 }
 
-Utils::FileNameList SelectableFilesModel::preservedFiles() const
+Utils::FilePaths SelectableFilesModel::preservedFiles() const
 {
-    return m_outOfBaseDirFiles.toList();
+    return Utils::toList(m_outOfBaseDirFiles);
 }
 
 bool SelectableFilesModel::hasCheckedFiles() const
@@ -335,7 +336,7 @@ bool SelectableFilesModel::hasCheckedFiles() const
     return m_root->checked != Qt::Unchecked;
 }
 
-void SelectableFilesModel::collectFiles(Tree *root, Utils::FileNameList *result) const
+void SelectableFilesModel::collectFiles(Tree *root, Utils::FilePaths *result) const
 {
     if (root->checked == Qt::Unchecked)
         return;
@@ -349,7 +350,7 @@ void SelectableFilesModel::collectFiles(Tree *root, Utils::FileNameList *result)
 QList<Glob> SelectableFilesModel::parseFilter(const QString &filter)
 {
     QList<Glob> result;
-    const QStringList list = filter.split(QLatin1Char(';'), QString::SkipEmptyParts);
+    const QStringList list = filter.split(QLatin1Char(';'), Qt::SkipEmptyParts);
     for (const QString &e : list) {
         QString entry = e.trimmed();
         Glob g;
@@ -362,7 +363,8 @@ QList<Glob> SelectableFilesModel::parseFilter(const QString &filter)
             g.matchString = entry.mid(1);
         } else {
             g.mode = Glob::REGEXP;
-            g.matchRegexp = QRegExp(entry, Qt::CaseInsensitive, QRegExp::Wildcard);
+            const QString re = QRegularExpression::wildcardToRegularExpression(entry);
+            g.matchRegexp = QRegularExpression(re, QRegularExpression::CaseInsensitiveOption);
         }
         result.append(g);
     }
@@ -550,7 +552,7 @@ SelectableFilesWidget::SelectableFilesWidget(QWidget *parent) :
                                              QLatin1String(HIDE_FILE_FILTER_DEFAULT)).toString();
 
     auto layout = new QGridLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     m_baseDirLabel->setText(tr("Source directory:"));
     m_baseDirChooser->setHistoryCompleter(QLatin1String("PE.AddToProjectDir.History"));
@@ -563,7 +565,7 @@ SelectableFilesWidget::SelectableFilesWidget(QWidget *parent) :
     connect(m_baseDirChooser, &Utils::PathChooser::validChanged,
             this, &SelectableFilesWidget::baseDirectoryChanged);
     connect(m_startParsingButton, &QAbstractButton::clicked,
-            this, [this]() { startParsing(m_baseDirChooser->fileName()); });
+            this, [this]() { startParsing(m_baseDirChooser->filePath()); });
 
     m_selectFilesFilterLabel->setText(tr("Select files matching:"));
     m_selectFilesFilterEdit->setText(selectFilter);
@@ -591,8 +593,8 @@ SelectableFilesWidget::SelectableFilesWidget(QWidget *parent) :
     layout->addWidget(m_progressLabel, static_cast<int>(SelectableFilesWidgetRows::Progress), 0, 1, 4);
 }
 
-SelectableFilesWidget::SelectableFilesWidget(const Utils::FileName &path,
-                                             const Utils::FileNameList &files, QWidget *parent) :
+SelectableFilesWidget::SelectableFilesWidget(const Utils::FilePath &path,
+                                             const Utils::FilePaths &files, QWidget *parent) :
     SelectableFilesWidget(parent)
 {
     resetModel(path, files);
@@ -601,6 +603,10 @@ SelectableFilesWidget::SelectableFilesWidget(const Utils::FileName &path,
 void SelectableFilesWidget::setAddFileFilter(const QString &filter)
 {
     m_selectFilesFilterEdit->setText(filter);
+    if (m_applyFiltersButton->isEnabled())
+        applyFilter();
+    else
+        m_filteringScheduled = true;
 }
 
 void SelectableFilesWidget::setBaseDirEditable(bool edit)
@@ -611,14 +617,14 @@ void SelectableFilesWidget::setBaseDirEditable(bool edit)
     m_startParsingButton->setVisible(edit);
 }
 
-Utils::FileNameList SelectableFilesWidget::selectedFiles() const
+Utils::FilePaths SelectableFilesWidget::selectedFiles() const
 {
-    return m_model ? m_model->selectedFiles() : Utils::FileNameList();
+    return m_model ? m_model->selectedFiles() : Utils::FilePaths();
 }
 
-Utils::FileNameList SelectableFilesWidget::selectedPaths() const
+Utils::FilePaths SelectableFilesWidget::selectedPaths() const
 {
-    return m_model ? m_model->selectedPaths() : Utils::FileNameList();
+    return m_model ? m_model->selectedPaths() : Utils::FilePaths();
 }
 
 bool SelectableFilesWidget::hasFilesSelected() const
@@ -626,7 +632,7 @@ bool SelectableFilesWidget::hasFilesSelected() const
     return m_model ? m_model->hasCheckedFiles() : false;
 }
 
-void SelectableFilesWidget::resetModel(const Utils::FileName &path, const Utils::FileNameList &files)
+void SelectableFilesWidget::resetModel(const Utils::FilePath &path, const Utils::FilePaths &files)
 {
     m_view->setModel(nullptr);
 
@@ -641,7 +647,7 @@ void SelectableFilesWidget::resetModel(const Utils::FileName &path, const Utils:
     connect(m_model, &SelectableFilesModel::checkedFilesChanged,
             this, &SelectableFilesWidget::selectedFilesChanged);
 
-    m_baseDirChooser->setFileName(path);
+    m_baseDirChooser->setFilePath(path);
     m_view->setModel(m_model);
 
     startParsing(path);
@@ -675,6 +681,7 @@ void SelectableFilesWidget::enableWidgets(bool enabled)
 
 void SelectableFilesWidget::applyFilter()
 {
+    m_filteringScheduled = false;
     if (m_model)
         m_model->applyFilter(m_selectFilesFilterEdit->text(), m_hideFilesFilterEdit->text());
 }
@@ -684,7 +691,7 @@ void SelectableFilesWidget::baseDirectoryChanged(bool validState)
     m_startParsingButton->setEnabled(validState);
 }
 
-void SelectableFilesWidget::startParsing(const Utils::FileName &baseDir)
+void SelectableFilesWidget::startParsing(const Utils::FilePath &baseDir)
 {
     if (!m_model)
         return;
@@ -694,7 +701,7 @@ void SelectableFilesWidget::startParsing(const Utils::FileName &baseDir)
     m_model->startParsing(baseDir);
 }
 
-void SelectableFilesWidget::parsingProgress(const Utils::FileName &fileName)
+void SelectableFilesWidget::parsingProgress(const Utils::FilePath &fileName)
 {
     m_progressLabel->setText(tr("Generating file list...\n\n%1").arg(fileName.toUserOutput()));
 }
@@ -706,11 +713,13 @@ void SelectableFilesWidget::parsingFinished()
 
     smartExpand(m_model->index(0,0, QModelIndex()));
 
-    const Utils::FileNameList preservedFiles = m_model->preservedFiles();
+    const Utils::FilePaths preservedFiles = m_model->preservedFiles();
     m_preservedFilesLabel->setText(tr("Not showing %n files that are outside of the base directory.\n"
                                       "These files are preserved.", nullptr, preservedFiles.count()));
 
     enableWidgets(true);
+    if (m_filteringScheduled)
+        applyFilter();
 }
 
 void SelectableFilesWidget::smartExpand(const QModelIndex &idx)
@@ -728,8 +737,8 @@ void SelectableFilesWidget::smartExpand(const QModelIndex &idx)
 // SelectableFilesDialogs
 //////////
 
-SelectableFilesDialogEditFiles::SelectableFilesDialogEditFiles(const Utils::FileName &path,
-                                                               const Utils::FileNameList &files,
+SelectableFilesDialogEditFiles::SelectableFilesDialogEditFiles(const Utils::FilePath &path,
+                                                               const Utils::FilePaths &files,
                                                                QWidget *parent) :
     QDialog(parent),
     m_filesWidget(new SelectableFilesWidget(path, files))
@@ -752,7 +761,7 @@ SelectableFilesDialogEditFiles::SelectableFilesDialogEditFiles(const Utils::File
     layout->addWidget(buttonBox);
 }
 
-Utils::FileNameList SelectableFilesDialogEditFiles::selectedFiles() const
+Utils::FilePaths SelectableFilesDialogEditFiles::selectedFiles() const
 {
     return m_filesWidget->selectedFiles();
 }
@@ -763,8 +772,8 @@ Utils::FileNameList SelectableFilesDialogEditFiles::selectedFiles() const
 //////////
 
 
-SelectableFilesDialogAddDirectory::SelectableFilesDialogAddDirectory(const Utils::FileName &path,
-                                                                     const Utils::FileNameList &files,
+SelectableFilesDialogAddDirectory::SelectableFilesDialogAddDirectory(const Utils::FilePath &path,
+                                                                     const Utils::FilePaths &files,
                                                                      QWidget *parent) :
     SelectableFilesDialogEditFiles(path, files, parent)
 {
