@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2020 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt Creator.
@@ -28,10 +28,11 @@
 #include <coreplugin/fileiconprovider.h>
 #include <coreplugin/fileutils.h>
 #include <coreplugin/icore.h>
-#include <coreplugin/removefiledialog.h>
 #include <coreplugin/vcsmanager.h>
 #include <projectexplorer/projectexplorerconstants.h>
 #include <utils/fileutils.h>
+#include <utils/removefiledialog.h>
+#include <utils/theme/theme.h>
 
 #include <QCoreApplication>
 #include <QDebug>
@@ -99,9 +100,10 @@ bool FileList::containsFile(File *file)
 ** ResourceFile
 */
 
-ResourceFile::ResourceFile(const QString &file_name)
+ResourceFile::ResourceFile(const QString &file_name, const QString &contents)
 {
     setFileName(file_name);
+    m_contents = contents;
 }
 
 ResourceFile::~ResourceFile()
@@ -118,28 +120,44 @@ Core::IDocument::OpenResult ResourceFile::load()
         return Core::IDocument::OpenResult::ReadError;
     }
 
-    QFile file(m_file_name);
-    if (!file.open(QIODevice::ReadOnly)) {
-        m_error_message = file.errorString();
-        return Core::IDocument::OpenResult::ReadError;
-    }
-    QByteArray data = file.readAll();
-    // Detect line ending style
-    m_textFileFormat = Utils::TextFileFormat::detect(data);
-    // we always write UTF-8 when saving
-    m_textFileFormat.codec = QTextCodec::codecForName("UTF-8");
-    file.close();
-
     clearPrefixList();
 
     QDomDocument doc;
 
-    QString error_msg;
-    int error_line, error_col;
-    if (!doc.setContent(data, &error_msg, &error_line, &error_col)) {
-        m_error_message = tr("XML error on line %1, col %2: %3")
-                    .arg(error_line).arg(error_col).arg(error_msg);
-        return Core::IDocument::OpenResult::CannotHandle;
+    if (m_contents.isEmpty()) {
+
+        // Regular file
+        QFile file(m_file_name);
+        if (!file.open(QIODevice::ReadOnly)) {
+            m_error_message = file.errorString();
+            return Core::IDocument::OpenResult::ReadError;
+        }
+        QByteArray data = file.readAll();
+        // Detect line ending style
+        m_textFileFormat = Utils::TextFileFormat::detect(data);
+        // we always write UTF-8 when saving
+        m_textFileFormat.codec = QTextCodec::codecForName("UTF-8");
+        file.close();
+
+        QString error_msg;
+        int error_line, error_col;
+        if (!doc.setContent(data, &error_msg, &error_line, &error_col)) {
+            m_error_message = tr("XML error on line %1, col %2: %3")
+                        .arg(error_line).arg(error_col).arg(error_msg);
+            return Core::IDocument::OpenResult::CannotHandle;
+        }
+
+    } else {
+
+        // Virtual file from qmake evaluator
+        QString error_msg;
+        int error_line, error_col;
+        if (!doc.setContent(m_contents, &error_msg, &error_line, &error_col)) {
+            m_error_message = tr("XML error on line %1, col %2: %3")
+                        .arg(error_line).arg(error_col).arg(error_msg);
+            return Core::IDocument::OpenResult::CannotHandle;
+        }
+
     }
 
     QDomElement root = doc.firstChildElement(QLatin1String("RCC"));
@@ -157,7 +175,7 @@ Core::IDocument::OpenResult ResourceFile::load()
         const QString language = relt.attribute(QLatin1String("lang"));
 
         const int idx = indexOfPrefix(prefix, language);
-        Prefix * p = 0;
+        Prefix *p = nullptr;
         if (idx == -1) {
             p = new Prefix(prefix, language);
             m_prefix_list.append(p);
@@ -172,6 +190,7 @@ Core::IDocument::OpenResult ResourceFile::load()
             const QString alias = felt.attribute(QLatin1String("alias"));
             File * const file = new File(p, fileName, alias);
             file->compress = felt.attribute(QLatin1String("compress"));
+            file->compressAlgo = felt.attribute(QLatin1String("compress-algo"));
             file->threshold = felt.attribute(QLatin1String("threshold"));
             p->file_list.append(file);
         }
@@ -208,6 +227,8 @@ QString ResourceFile::contents() const
                 felt.setAttribute(QLatin1String("alias"), file.alias);
             if (!file.compress.isEmpty())
                 felt.setAttribute(QLatin1String("compress"), file.compress);
+            if (!file.compressAlgo.isEmpty())
+                felt.setAttribute(QLatin1String("compress-algo"), file.compressAlgo);
             if (!file.threshold.isEmpty())
                 felt.setAttribute(QLatin1String("threshold"), file.threshold);
         }
@@ -430,6 +451,18 @@ QString ResourceFile::absolutePath(const QString &rel_path) const
     return QDir::cleanPath(rc);
 }
 
+void ResourceFile::orderList()
+{
+    for (Prefix *p : qAsConst(m_prefix_list)) {
+        std::sort(p->file_list.begin(), p->file_list.end(), [&](File *f1, File *f2) {
+            return *f1 < *f2;
+        });
+    }
+
+    if (!save())
+        m_error_message = tr("Cannot save file.");
+}
+
 bool ResourceFile::contains(const QString &prefix, const QString &lang, const QString &file) const
 {
     int pref_idx = indexOfPrefix(prefix, lang);
@@ -456,8 +489,7 @@ bool ResourceFile::contains(int pref_idx, const QString &file) const
 {
     const QChar slash = QLatin1Char('/');
     QString result = QString(slash);
-    for (int i = 0; i < prefix.size(); ++i) {
-        const QChar c = prefix.at(i);
+    for (const QChar c : prefix) {
         if (c == slash && result.at(result.size() - 1) == slash)
             continue;
         result.append(c);
@@ -547,8 +579,8 @@ void ResourceFile::clearPrefixList()
 ResourceModel::ResourceModel(QObject *parent)
     : QAbstractItemModel(parent), m_dirty(false)
 {
-    m_prefixIcon = Core::FileIconProvider::overlayIcon(QStyle::SP_DirIcon,
-        QIcon(QLatin1String(ProjectExplorer::Constants::FILEOVERLAY_QRC)), QSize(16, 16));
+    static QIcon resourceFolderIcon = Core::FileIconProvider::directoryIcon(QLatin1String(ProjectExplorer::Constants::FILEOVERLAY_QRC));
+    m_prefixIcon = resourceFolderIcon;
 }
 
 void ResourceModel::setDirty(bool b)
@@ -567,10 +599,10 @@ QModelIndex ResourceModel::index(int row, int column, const QModelIndex &parent)
     if (column != 0)
         return QModelIndex();
 
-    void * internalPointer = 0;
+    void *internalPointer = nullptr;
     if (parent.isValid()) {
         void * const pip = parent.internalPointer();
-        if (pip == 0)
+        if (!pip)
             return QModelIndex();
 
         // File node
@@ -598,7 +630,7 @@ QModelIndex ResourceModel::parent(const QModelIndex &index) const
         return QModelIndex();
 
     void * const internalPointer = index.internalPointer();
-    if (internalPointer == 0)
+    if (!internalPointer)
         return QModelIndex();
     Node * const node = reinterpret_cast<Node *>(internalPointer);
     Prefix * const prefix = node->prefix();
@@ -671,6 +703,11 @@ QList<QModelIndex> ResourceModel::nonExistingFiles() const
     return files;
 }
 
+void ResourceModel::orderList()
+{
+    m_resource_file.orderList();
+}
+
 Qt::ItemFlags ResourceModel::flags(const QModelIndex &index) const
 {
     Qt::ItemFlags f = QAbstractItemModel::flags(index);
@@ -759,7 +796,7 @@ QVariant ResourceModel::data(const QModelIndex &index, int role) const
                 if (iconFileExtension(path))
                     file->icon = QIcon(path);
                 else
-                    file->icon = Core::FileIconProvider::icon(path);
+                    file->icon = Core::FileIconProvider::icon(QFileInfo(path));
             }
             if (!file->icon.isNull())
                 result = file->icon;
@@ -780,7 +817,7 @@ QVariant ResourceModel::data(const QModelIndex &index, int role) const
             // File node
             Q_ASSERT(file);
             if (!file->exists())
-                result = QBrush(QColor(Qt::red));
+                result = Utils::creatorTheme()->color(Utils::Theme::TextColorError);
         }
         break;
     default:
@@ -797,7 +834,7 @@ bool ResourceModel::setData(const QModelIndex &index, const QVariant &value, int
         return false;
 
     const QDir baseDir = QFileInfo(fileName()).absoluteDir();
-    Utils::FileName newFileName = Utils::FileName::fromUserInput(
+    Utils::FilePath newFileName = Utils::FilePath::fromUserInput(
                 baseDir.absoluteFilePath(value.toString()));
 
     if (newFileName.isEmpty())
@@ -1104,12 +1141,12 @@ QString ResourceModel::resourcePath(const QString &prefix, const QString &file)
 QMimeData *ResourceModel::mimeData(const QModelIndexList &indexes) const
 {
     if (indexes.size() != 1)
-        return 0;
+        return nullptr;
 
     QString prefix, file;
     getItem(indexes.front(), prefix, file);
     if (prefix.isEmpty() || file.isEmpty())
-        return 0;
+        return nullptr;
 
     // DnD format of Designer 4.4
     QDomDocument doc;
@@ -1118,7 +1155,7 @@ QMimeData *ResourceModel::mimeData(const QModelIndexList &indexes) const
     elem.setAttribute(QLatin1String("file"), resourcePath(prefix, file));
     doc.appendChild(elem);
 
-    QMimeData *rc = new QMimeData;
+    auto rc = new QMimeData;
     rc->setText(doc.toString());
     return rc;
 }
@@ -1140,7 +1177,7 @@ public:
             const QString &fileName, const QString &alias)
             : EntryBackup(model, prefixIndex, fileName), m_fileIndex(fileIndex),
             m_alias(alias) { }
-    void restore() const;
+    void restore() const override;
 };
 
 void FileEntryBackup::restore() const
@@ -1163,7 +1200,7 @@ public:
     PrefixEntryBackup(ResourceModel &model, int prefixIndex, const QString &prefix,
             const QString &language, const QList<FileEntryBackup> &files)
             : EntryBackup(model, prefixIndex, prefix), m_language(language), m_files(files) { }
-    void restore() const;
+    void restore() const override;
 };
 
 void PrefixEntryBackup::restore() const
@@ -1217,12 +1254,12 @@ EntryBackup * RelativeResourceModel::removeEntry(const QModelIndex &index)
             deleteItem(index);
             return new FileEntryBackup(*this, prefixIndex.row(), index.row(), fileNameBackup, aliasBackup);
         }
-        Core::RemoveFileDialog removeFileDialog(fileNameBackup, Core::ICore::mainWindow());
+        Utils::RemoveFileDialog removeFileDialog(fileNameBackup, Core::ICore::dialogParent());
         if (removeFileDialog.exec() == QDialog::Accepted) {
             deleteItem(index);
             Core::FileUtils::removeFile(fileNameBackup, removeFileDialog.isDeleteFileChecked());
             return new FileEntryBackup(*this, prefixIndex.row(), index.row(), fileNameBackup, aliasBackup);
         }
-        return 0;
+        return nullptr;
     }
 }
